@@ -39,6 +39,7 @@ using Poco::NumberFormatter;
 using Poco::SyntaxException;
 using Poco::icompare;
 using Poco::trimInPlace;
+using namespace std::string_literals;
 
 
 namespace Poco {
@@ -117,6 +118,8 @@ inline void Parser::append(std::string& decl, const std::string& token)
 			token != "," &&
 			token != "[" &&
 			token != "]" &&
+			token != "[[" &&
+			token != "]]" &&
 			last != '~' &&
 			last != ':' &&
 			last != '(' &&
@@ -133,6 +136,7 @@ inline void Parser::append(std::string& decl, const std::string& token)
 	 || token == "static"
 	 || token == "mutable"
 	 || token == "inline"
+	 || token == "virtual"
 	 || token == "volatile"
 	 || token == "register"
 	 || token == "thread_local")
@@ -212,6 +216,18 @@ const Token* Parser::parseNameSpace(const Token* pNext)
 		_access = Symbol::ACC_PUBLIC;
 		std::string name = pNext->tokenString();
 		pNext = next();
+
+		if (isOperator(pNext, OperatorToken::OP_ASSIGN))
+		{
+			pNext = next();
+			while (!isOperator(pNext, OperatorToken::OP_SEMICOLON) && !isEOF(pNext))
+			{
+				pNext = next();
+			}
+			if (!isEOF(pNext)) pNext = next();
+			return pNext;
+		}
+
 		expectOperator(pNext, OperatorToken::OP_OPENBRACE, "{");
 
 		std::string fullName = currentNameSpace()->fullName();
@@ -379,7 +395,7 @@ const Token* Parser::parseClassMembers(const Token* pNext, Struct* /*pClass*/)
 	poco_assert (isOperator(pNext, OperatorToken::OP_OPENBRACE));
 
 	pNext = next();
-	while (pNext->is(Token::IDENTIFIER_TOKEN) || pNext->is(Token::KEYWORD_TOKEN) || isOperator(pNext, OperatorToken::OP_COMPL))
+	while (pNext->is(Token::IDENTIFIER_TOKEN) || pNext->is(Token::KEYWORD_TOKEN) || isOperator(pNext, OperatorToken::OP_COMPL) || isOperator(pNext, OperatorToken::OP_DBL_COLON) || isOperator(pNext, OperatorToken::OP_DBL_OPENBRACKET))
 	{
 		switch (pNext->asInteger())
 		{
@@ -574,6 +590,11 @@ const Token* Parser::parseVarFunc(const Token* pNext)
 const Token* Parser::parseVarFunc(const Token* pNext, std::string& decl)
 {
 	_pCurrentSymbol = 0;
+	std::string attrs;
+	if (isOperator(pNext, OperatorToken::OP_DBL_OPENBRACKET))
+	{
+		pNext = parseAttributes(pNext, attrs);
+	}
 	if (isKeyword(pNext, IdentifierToken::KW_EXTERN))
 	{
 		pNext = parseExtern(pNext);
@@ -582,11 +603,18 @@ const Token* Parser::parseVarFunc(const Token* pNext, std::string& decl)
 	{
 		append(decl, pNext);
 		pNext = next();
-		bool isOp = false;
-		while (!isOperator(pNext, OperatorToken::OP_SEMICOLON) && !isOperator(pNext, OperatorToken::OP_OPENPARENT) && !isEOF(pNext))
+		bool isOperatorKeyword = false;
+		int tmplDepth = 0;
+		while (!isOperator(pNext, OperatorToken::OP_SEMICOLON) && !(tmplDepth == 0 && isOperator(pNext, OperatorToken::OP_OPENPARENT)) && !isEOF(pNext))
 		{
+			if (!isOperatorKeyword && isOperator(pNext, OperatorToken::OP_LT)) 
+				tmplDepth++;
+			else if (!isOperatorKeyword && isOperator(pNext, OperatorToken::OP_GT) && tmplDepth > 0)
+				tmplDepth--;
+			else if (!isOperatorKeyword && isOperator(pNext, OperatorToken::OP_SHR) && tmplDepth > 1)
+				tmplDepth -= 2;
 			append(decl, pNext);
-			isOp = isKeyword(pNext, IdentifierToken::KW_OPERATOR);
+			isOperatorKeyword = isKeyword(pNext, IdentifierToken::KW_OPERATOR);
 			pNext = next();
 		}
 		if (isOperator(pNext, OperatorToken::OP_SEMICOLON))
@@ -595,13 +623,14 @@ const Token* Parser::parseVarFunc(const Token* pNext, std::string& decl)
 			if (!currentNameSpace()->lookup(name))
 			{
 				Variable* pVar = new Variable(decl, currentNameSpace());
+				pVar->setAttributeList(attrs);
 				addSymbol(pVar, static_cast<int>(_istr.getCurrentLineNumber()));
 			}
 			pNext = next();
 		}
 		else if (isOperator(pNext, OperatorToken::OP_OPENPARENT))
 		{
-			if (isOp)
+			if (isOperatorKeyword)
 			{
 				decl += " (";
 				pNext = next();
@@ -610,7 +639,7 @@ const Token* Parser::parseVarFunc(const Token* pNext, std::string& decl)
 				pNext = next();
 				expectOperator(pNext, OperatorToken::OP_OPENPARENT, "(");
 			}
-			pNext = parseFunc(pNext, decl);
+			pNext = parseFunc(pNext, attrs, decl);
 		}
 	}
 	_pCurrentSymbol = 0;
@@ -640,7 +669,7 @@ const Token* Parser::parseExtern(const Token* pNext)
 }
 
 
-const Token* Parser::parseFunc(const Token* pNext, std::string& decl)
+const Token* Parser::parseFunc(const Token* pNext, const std::string& attrs, std::string& decl)
 {
 	poco_assert (isOperator(pNext, OperatorToken::OP_OPENPARENT));
 
@@ -650,6 +679,7 @@ const Token* Parser::parseFunc(const Token* pNext, std::string& decl)
 	if (name.find(':') == std::string::npos)
 	{
 		pFunc = new Function(decl, currentNameSpace());
+		pFunc->setAttributeList(attrs);
 		addSymbol(pFunc, line);
 	}
 	pNext = parseParameters(pNext, pFunc);
@@ -908,6 +938,25 @@ const Token* Parser::parseIdentifier(const Token* pNext, std::string& id)
 }
 
 
+const Poco::Token* Parser::parseAttributes(const Poco::Token* pNext, std::string& attrs)
+{
+	poco_assert (isOperator(pNext, OperatorToken::OP_DBL_OPENBRACKET));
+	append(attrs, pNext);
+	pNext = next();
+	while (pNext && !isOperator(pNext, OperatorToken::OP_DBL_CLOSBRACKET))
+	{
+		append(attrs, pNext);
+		pNext = next();
+	}
+	if (pNext) 
+	{
+		append(attrs, pNext);
+		pNext = next();
+	}
+	return pNext;
+}
+
+
 void Parser::addSymbol(Symbol* pSymbol, int lineNumber, bool addGST)
 {
 	pSymbol->setLineNumber(lineNumber);
